bands_hessian — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bands_hessian

property ElectronicBandStructure.bands_hessian

  Bands hessian is a numpy array that stores each band hessian in a list that corresponds to the self.kpoints Shape = [n_kpoints,3,3,n_bands], where the second and third dimension represent d/dx,d/dy,d/dz

  Returns:

    np.ndarray – Bands hessian is a numpy array that stores each band hessian in a list that corresponds to the self.kpoints Shape = [n_kpoints,3,3,n_bands], where the second and third dimension represent d/dx,d/dy,d/dz